@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 use 5.006;
 use strict;
 use warnings;
@@ -381,7 +381,10 @@ sub TO_JSON {
 	return $output;
 }
 
-sub DESTROY {}
+sub DESTROY {
+	my ($self) = @_;
+	(reftype $self eq 'HASH' ? %{$self} : @{$self}) = ();
+}
 
 sub AUTOLOAD : lvalue {
 	my $classname =  ref $_[0];
@@ -410,7 +413,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
